# Flytekit Modin Plugin

Modin is a pandas-accelerator that helps handle large datasets. It is a light-weight extension that is similar to the pandas API. It uses the concept of parallelism to reduce overhead, and improve the performance of pandas operations by leveraging the compute resources available.

This plugin supports Modin as a data type.

To install the plugin, run the following command:

```bash
pip install flytekitplugins-modin
```

All [examples](https://docs.flyte.org/projects/cookbook/en/latest/auto/integrations/flytekit_plugins/modin_examples/index.html) can be found in the documentation.
